@@ -1,4 +1,4 @@
-package Pcore::WebDriver v0.1.2;
+package Pcore::WebDriver v0.1.3;
 
 use Pcore -dist, -const, -class, -result,
   -export => {
@@ -1053,6 +1053,45 @@ Pcore::WebDriver - asynchronous WebDriver protocol implementation
 
 =head1 SYNOPSIS
 
+    use Pcore::WebDriver;
+
+    my $cv = AE::cv;
+
+    my $wd1 = Pcore::WebDriver->new_phantomjs;
+    my $wd2 = Pcore::WebDriver->new_chrome;
+
+    # manage several browsers simultaneously from the single process
+    $wd1->get('https://www.google.com/', sub ($res) {
+        die $res if !$res;
+
+        $wd1->find_element_by_xpath(..., sub ($web_element) {
+            return;
+        });
+
+        return;
+    });
+
+    # this is a non-blocking call
+    $wd2->get('https://www.facebook.com/', sub ($res) {
+        die $res if !$res;
+
+        # also non-blocking
+        $wd1->find_element_by_xpath(..., sub ($web_element) {
+            return;
+        });
+
+        return;
+    });
+
+    # calls without defined callback, or called with defined return context (defined wantarray) - are blocking
+    # blocking call:
+    my $res = $wd1->find_element_by_id('id');
+
+    # also blocking:
+    $wd1->find_element_by_id('id');
+
+    $cv->recv;
+
 =head1 DESCRIPTION
 
 =head1 ATTRIBUTES
